import numpy as np
import pandas as pd
from scipy.stats import ttest_ind, chi2_contingency, norm
import matplotlib.pyplot as plt

# 1. サンプルデータ作成（架空のカフェチェーン売上データ）
np.random.seed(42)
city_a_sales = np.random.normal(500, 50, 30)  # 都市Aの1ヶ月の売上（ドル）
city_b_sales = np.random.normal(520, 55, 30)  # 都市Bの1ヶ月の売上（ドル）

# カテゴリデータ（例えば、ドリンクの注文種類）
orders = np.array([
    [50, 30],  # 都市A: コーヒー、紅茶
    [40, 60]   # 都市B: コーヒー、紅茶
])

# 2. t検定（売上の比較）
t_stat, p_value = ttest_ind(city_a_sales, city_b_sales)
print("=== t検定: 売上の比較 ===")
print(f"t値: {t_stat:.2f}, p値: {p_value:.4f}")
if p_value < 0.05:
    print("都市Aと都市Bの売上に有意な差があります。")
else:
    print("都市Aと都市Bの売上に有意な差はありません。")

# 3. カイ二乗検定（注文種類の比較）
chi2, p, _, _ = chi2_contingency(orders)
print("\n=== カイ二乗検定: 注文種類の比較 ===")
print(f"カイ二乗値: {chi2:.2f}, p値: {p:.4f}")
if p < 0.05:
    print("都市Aと都市Bで注文種類に有意な差があります。")
else:
    print("都市Aと都市Bで注文種類に有意な差はありません。")

# 4. 信頼区間の計算（都市Aの売上平均）
mean_sales_a = np.mean(city_a_sales)
std_err_a = np.std(city_a_sales, ddof=1) / np.sqrt(len(city_a_sales))
ci = norm.interval(0.95, loc=mean_sales_a, scale=std_err_a)
print("\n=== 信頼区間 ===")
print(f"都市Aの売上平均: {mean_sales_a:.2f}")
print(f"95%信頼区間: {ci}")

# 5. データの可視化
# 都市Aと都市Bの売上ヒストグラム
plt.hist(city_a_sales, bins=10, alpha=0.7, label="都市Aの売上", color="blue", edgecolor="black")
plt.hist(city_b_sales, bins=10, alpha=0.7, label="都市Bの売上", color="orange", edgecolor="black")
plt.title("都市Aと都市Bの売上分布")
plt.xlabel("売上（ドル）")
plt.ylabel("頻度")
plt.legend()
plt.show()

# 注文種類の棒グラフ
categories = ["コーヒー", "紅茶"]
x = np.arange(len(categories))
width = 0.35

plt.bar(x - width/2, orders[0], width, label="都市A", color="blue")
plt.bar(x + width/2, orders[1], width, label="都市B", color="orange")
plt.xticks(x, categories)
plt.title("注文種類の分布")
plt.ylabel("注文数")
plt.legend()
plt.show()
