import numpy as np
import pandas as pd
from scipy.stats import pearsonr, spearmanr
from sklearn.linear_model import LinearRegression
import matplotlib.pyplot as plt

# 1. サンプルデータ作成（架空のフィットネスデータ）
np.random.seed(42)
hours_of_exercise = np.random.uniform(1, 10, 50)  # 週あたりの運動時間（1〜10時間）
calories_burned = 200 * hours_of_exercise + np.random.normal(0, 50, 50)  # 消費カロリー（ノイズ付き）
steps_taken = np.random.uniform(5000, 20000, 50)  # 歩数（非線形な関係）

# データをDataFrameに格納
df = pd.DataFrame({
    "ExerciseHours": hours_of_exercise,
    "CaloriesBurned": calories_burned,
    "StepsTaken": steps_taken
})

# 2. ピアソン相関係数
pearson_corr, pearson_p = pearsonr(df["ExerciseHours"], df["CaloriesBurned"])
print("=== ピアソン相関係数 ===")
print(f"相関係数: {pearson_corr:.2f}, p値: {pearson_p:.4f}")
if pearson_p < 0.05:
    print("運動時間と消費カロリーには有意な線形関係があります。")
else:
    print("運動時間と消費カロリーには有意な線形関係はありません。")

# 3. スピアマン相関係数
spearman_corr, spearman_p = spearmanr(df["ExerciseHours"], df["StepsTaken"])
print("\n=== スピアマン相関係数 ===")
print(f"相関係数: {spearman_corr:.2f}, p値: {spearman_p:.4f}")
if spearman_p < 0.05:
    print("運動時間と歩数には有意な順位相関があります。")
else:
    print("運動時間と歩数には有意な順位相関はありません。")

# 4. 単回帰分析（運動時間 -> 消費カロリー）
model = LinearRegression()
model.fit(df[["ExerciseHours"]], df["CaloriesBurned"])
df["PredictedCalories"] = model.predict(df[["ExerciseHours"]])

# モデルのパラメータ
print("\n=== 単回帰分析 ===")
print(f"回帰直線の傾き: {model.coef_[0]:.2f}")
print(f"回帰直線の切片: {model.intercept_:.2f}")

# プロット（運動時間と消費カロリー）
plt.scatter(df["ExerciseHours"], df["CaloriesBurned"], color="blue", label="実測値")
plt.plot(df["ExerciseHours"], df["PredictedCalories"], color="red", label="回帰直線")
plt.title("単回帰分析: 運動時間と消費カロリー")
plt.xlabel("週あたりの運動時間（時間）")
plt.ylabel("消費カロリー")
plt.legend()
plt.show()
